@@ -1,31 +1,9 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 #
-# Copyright 2016 by Shaheed Haque (srhaque@theiet.org)
-# Copyright 2016 by Stephen Kelly (steveire@gmail.com)
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-#
-# 1. Redistributions of source code must retain the copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-# 3. The name of the author may not be used to endorse or promote products
-#    derived from this software without specific prior written permission.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+# SPDX-FileCopyrightText: 2016 Shaheed Haque <srhaque@theiet.org>
+# SPDX-FileCopyrightText: 2016 Stephen Kelly <steveire@gmail.com>
 #
+# SPDX-License-Identifier: BSD-3-Clause
 
 """SIP file generator for PyQt."""
 
@@ -34,12 +12,10 @@ import argparse
 import gettext
 import inspect
 import logging
-import os
-import re
 import sys
 import traceback
 from clang import cindex
-from clang.cindex import AccessSpecifier, AvailabilityKind, CursorKind, SourceRange, StorageClass, TokenKind, TypeKind, TranslationUnit
+from clang.cindex import AccessSpecifier, AvailabilityKind, CursorKind, SourceRange, TokenKind, TypeKind, TranslationUnit
 
 import rules_engine
 
@@ -806,7 +782,7 @@ def main(argv=None):
         body, includes = g.create_sip(args.source, args.include_filename)
         with open(args.output, "w") as outputFile:
             outputFile.write(body)
-    except Exception as e:
+    except Exception:
         tbk = traceback.format_exc()
         print(tbk)
         return -1
